@@ -31,11 +31,12 @@ def validate_timestamp(input):
         m = re.search(p, input)
         # matched the ReGex otherwise False
         if m is None:
-            raise ValueError("Input timestamp as HH:MM:SS")
+            return False
     return True
 
 
 def validate_ipv4(input):
+    # think -1 should be string
     if input != -1:
         try:
             ipaddress.IPv4Address(input)
@@ -49,4 +50,5 @@ def validate_ipv6(input):
             ipaddress.IPv6Address(input)
         except Exception as e:
             return False
-    return True
\ No newline at end of file
+    return True
+
